@@ -14,5 +14,5 @@
 from .DraperAdder import DraperAdderGate
 from .Qft import QuantumFourierTransformGate
 from .UniformRotation import UniformRotationGate, MultiControlledXGate
-from .MottonenStatePreparation import MöttönenStatePreparationGate
+from .MöttönenStatePreparation import MöttönenStatePreparationGate
 from .FlipFlopQuantumRam import FFQramDb, FFQramEntry
\ No newline at end of file
